from distutils.core import setup

setup(
    name = 'elz_test',
    version = '1.0.0',
    py_modules=['elz_test'],
    author = 'elizaBambooChen',
    author_email = 'elizabamboochen@gmail.com',
    url='http://www.headfirstlabs.com',
    description='A test codes from Head First in Python',
    )
    
    
    
